@@ -1,5 +1,5 @@
 //
-// $Id: File.cc 1.7 Tue, 07 Dec 1999 12:14:47 -0800 yuri $
+// $Id: File.cc 1.11 Mon, 22 May 2000 13:47:40 -0700 cengiz $
 //
 // system.cc
 // Author: Ramesh Govindan <govindan@isi.edu>
@@ -225,7 +225,7 @@ Socket::Socket(int ds,FileMode fm, const Handler &rh, const Handler &wh) :
 	File(ds, fm, rh, wh) {
 }
 int Socket::setopt(int level, int optname, const void *optval, size_t optlen) {
-	return ::setsockopt(descriptor_, level, optname, optval, (SOCKLEN_T) optlen);
+	return ::setsockopt(descriptor_, level, optname, (char *) optval, (SOCKLEN_T) optlen);
 }
 
 DatagramSocket::DatagramSocket(const Handler& rh,
@@ -915,10 +915,10 @@ DiskFile::lock()
 {
     int	retval;
 
-#ifdef HAVE_FLOCK
-    retval = ::flock(descriptor_, LOCK_EX|LOCK_NB);
-#elif HAVE_LOCKF
+#ifdef HAVE_LOCKF
     retval = ::lockf(descriptor_, F_LOCK, 0);
+#elif HAVE_FLOCK
+    retval = ::flock(descriptor_, LOCK_EX|LOCK_NB);
 #else
     retval = 0;
 #endif
@@ -1012,10 +1012,10 @@ openPidFile(const char* name)
         exit(2);
     }
 
-#ifdef HAVE_FLOCK
-    retval = ::flock(pidDescriptor, LOCK_EX|LOCK_NB);
-#elif HAVE_LOCKF
+#ifdef HAVE_LOCKF
     retval = ::lockf(pidDescriptor, F_LOCK, 0);
+#elif HAVE_FLOCK
+    retval = ::flock(pidDescriptor, LOCK_EX|LOCK_NB);
 #else
     retval = 0;
 #endif
@@ -1082,17 +1082,11 @@ closePidFile()
     return;
 }
 
-void
-daemonize()
+volatile void daemonize()
 {
     int		t;
     Signal*	sig;
 
-    // Ignore several signals
-    sig = new Signal("ttou", NULL);
-    sig = new Signal("ttin", NULL);
-    sig = new Signal("tstp", NULL);
-
     // Fork once
     switch (fork()) {
         case 0:
@@ -1104,60 +1098,24 @@ daemonize()
             exit(0);
     }
 
-#ifdef SETPGRP_VOID
-    t = setpgrp();
-    if (t < 0) {
-        perror("daemonize: setprgp");
-        exit(1);
+    int fd = open("/dev/null", O_RDWR, 0);
+    if (fd == -1) {
+       perror("daemonize: fork");
+       exit(1);
     }
 
-    sig = new Signal("hup", NULL);
-
-    switch (fork()) {
-        case 0:
-            break;
-        case -1:
-            perror("daemonize: fork");
-            exit(1);
-        default:
-            exit(0);
-    } 
-#else // SETPRGP_VOID
-    t = setpgrp(0, getpid());
-    if (t < 0) {
-        perror("daemonize: setpgrp");
-        exit(1);
+    if (setsid() == -1) {
+       perror("daemonize: fork");
+       exit(1);
     }
-    
-    while ((t = open("/dev/tty", O_RDWR, 0)) == -1 && errno == EINTR);
-    if (t >= 0) {
-        if (ioctl(t, TIOCNOTTY, (caddr_t) 0) < 0) {
-            perror("daemonize: ioctl(TIOCNOTTY)");
-            exit(1);
-        }
-        close(t);
-    }
-#endif // SETPGRP_VOID
 
-    // Can close all open files, and reset umask
-    {
-#ifndef	NOFILE
-#ifdef	_NFILE
-#define	NOFILE	_NFILE
-#else	/* _NFILE */
-#ifdef	OPEN_MAX
-#define	NOFILE	OPEN_MAX
-#else	/* OPEN_MAX */
-#define	NOFILE	20
-#endif	/* OPEN_MAX */
-#endif	/* _NFILE */
-#endif	/* NOFILE */
-	t = NOFILE;
-	do {
-            (void) close(t);
-	} while (--t);
-
-    }
+    if (isatty(STDIN_FILENO))
+       dup2(fd, STDIN_FILENO);
+    if (isatty(STDOUT_FILENO))
+       dup2(fd, STDOUT_FILENO);
+    if (isatty(STDERR_FILENO))
+       dup2(fd, STDERR_FILENO);
+    if (fd > 2) close(fd);
 	    
     /* Reset umask */
     umask(022);
