@@ -1,4 +1,4 @@
-//  $Id: schema_rpsl.cc 1.9 Wed, 02 Feb 2000 18:12:52 -0800 cengiz $
+//  $Id: schema_rpsl.cc 1.10 Tue, 30 May 2000 17:13:48 -0700 cengiz $
 //
 //  Copyright (c) 1994 by the University of Southern California
 //  All rights reserved.
@@ -351,7 +351,7 @@ attr:  tech-c               mandatory,  multiple, lookup
 attr:  mnt-by               mandatory,  multiple, lookup " CMN_ATTRS "
 
 class: test
-attr: test syntax(date)
+attr: test syntax(special, peer)
 ";
 
 void Schema::addClass(AttrClass *clss) {
